@@ -1,4 +1,4 @@
-// $Id: callback.h,v 1.2 2002/02/17 18:53:39 murrayc Exp $ -*- c++ -*-
+// $Id: callback.h 589 2004-02-13 17:26:18Z murrayc $ -*- c++ -*-
 
 /* callback.h
  *
@@ -36,10 +36,11 @@ namespace Gnome
 namespace Conf
 {
 
-typedef SigC::Slot2<void, guint, Entry> Callback;
+typedef sigc::slot<void, guint, Entry> Callback;
 
 class Client;
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 class CallbackHolder
 {
 public:
@@ -51,9 +52,10 @@ public:
 
   Callback m_Slot;
 
-  static void destroy (void *data);
-  static void call (GConfClient *client, guint i, GConfEntry *entry, void *data);  
+  static void destroy(void *data);
+  static void call(GConfClient *client, guint i, GConfEntry *entry, void *data);  
 };
+#endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 } /* namespace Conf */
 } /* namespace Gnome */
